==> icons-vue-0.3.0.tgz: package/es/calculator/32.js <==
import { _ as _objectSpread2, a as _defineProperty } from '../chunk-75bb93d0.js';
import { getAttributes } from '@rocketsoftware/icon-helpers';

var virtual_Calculator32 = {
  name: 'Calculator32',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = getAttributes(_objectSpread2({
      width: '32',
      height: '32',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = _defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class = svgData.class || {}; // may be no static class

      svgData.class[data.class] = true;
    } // remove style set by getAttributes


    delete svgData.attrs.style; // combine incoming staticStyle, style with default willChange

    svgData.style = _objectSpread2({
      willChange: 'transform'
    }, data.staticStyle, {}, data.style);
    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('path', {
      attrs: {
        "d": "M26,4V28H6V4H26m0-2H6A2,2,0,0,0,4,4V28a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V4A2,2,0,0,0,26,2Z"
      }
    }), createElement('path', {
      attrs: {
        "d": "M9 23H11V25H9zM21 23H23V25H21zM9 18H11V20H9zM21 18H23V20H21zM9 13H11V15H9zM15 23H17V25H15zM15 18H17V20H15zM15 13H17V15H15zM21 13H23V15H21zM9 7H23V10H9z"
      }
    }), children]);
  }
};

export default virtual_Calculator32;

==> icons-vue-0.6.0.tgz: package/es/calculator/32.js <==
import { _ as _objectSpread2, a as _defineProperty } from '../_rollupPluginBabelHelpers-8169a350.js';
import { getAttributes } from '@rocketsoftware/icon-helpers';

var virtual_Calculator32 = {
  name: 'Calculator32',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = getAttributes(_objectSpread2({
      width: '32',
      height: '32',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = _defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class = svgData.class || {}; // may be no static class

      svgData.class[data.class] = true;
    } // remove style set by getAttributes


    delete svgData.attrs.style; // combine incoming staticStyle, style with default willChange

    svgData.style = _objectSpread2({
      willChange: 'transform'
    }, data.staticStyle, {}, data.style);
    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('path', {
      attrs: {
        "d": "M26,4V28H6V4H26m0-2H6A2,2,0,0,0,4,4V28a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V4A2,2,0,0,0,26,2Z"
      }
    }), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "2",
        "x": "9",
        "y": "23"
      }
    }), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "2",
        "x": "21",
        "y": "23"
      }
    }), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "2",
        "x": "9",
        "y": "18"
      }
    }), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "2",
        "x": "21",
        "y": "18"
      }
    }), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "2",
        "x": "9",
        "y": "13"
      }
    }), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "2",
        "x": "15",
        "y": "23"
      }
    }), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "2",
        "x": "15",
        "y": "18"
      }
    }), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "2",
        "x": "15",
        "y": "13"
      }
    }), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "2",
        "x": "21",
        "y": "13"
      }
    }), createElement('rect', {
      attrs: {
        "width": "14",
        "height": "3",
        "x": "9",
        "y": "7"
      }
    }), children]);
  }
};

export default virtual_Calculator32;
